@@ -20,6 +20,7 @@ from nonebot.plugin import PluginMetadata
 
 from .img_tool import simple_text, multi_text, calculate_text_size, ImageFactory, Box
 
+
 # 功能的数据信息
 @dataclass
 class FuncData:
@@ -29,6 +30,7 @@ class FuncData:
     brief_des: str
     detail_des: str
 
+
 # 插件菜单的数据信息
 @dataclass
 class PluginMenuData:
@@ -38,6 +40,7 @@ class PluginMenuData:
     funcs: List[FuncData]
     template: str
 
+
 class PicTemplate(metaclass=abc.ABCMeta):  # 模板类
     def __init__(self):
         pass
@@ -76,7 +79,6 @@ class PicTemplate(metaclass=abc.ABCMeta):  # 模板类
         """
         pass
 
-
     @abc.abstractmethod
     def generate_command_details(self, func_data: FuncData) -> Image:
         """
@@ -86,6 +88,7 @@ class PicTemplate(metaclass=abc.ABCMeta):  # 模板类
         """
         pass
 
+
 class Template(PicTemplate):
     def __init__(self):
         super().__init__()
@@ -282,14 +285,25 @@ class Template(PicTemplate):
             )
         # 获取table尺寸
         table_size = table.img.size
-        # usage的文字描述
-        usage_text = multi_text('用法：' + plugin_data.usage,
-                                box_size=(table_size[0] - 30, 0),
+        usage_basic_text = simple_text('用法：',
+                                       size=self.basic_font_size,
+                                       color=self.colors['blue'],
+                                       font=self.using_font)
+        usage_text = multi_text(plugin_data.usage,
+                                box_size=(table_size[0]-30-usage_basic_text.size[0]-10, 0),
                                 default_font=self.using_font,
                                 default_color=self.colors['blue'],
                                 default_size=self.basic_font_size
                                 )
-        usage_text_size = usage_text.size
+        # 合成usage文字图片
+        usage_img = ImageFactory(
+            Image.new('RGBA',
+                      (usage_text.size[0] + 10 + usage_basic_text.size[0], max((usage_text.size[1], usage_basic_text.size[1]))),
+                      self.colors['white'])
+        )
+        usage_img.img_paste(usage_basic_text, (0, 0), isalpha=True)
+        usage_img.img_paste(usage_text, (usage_basic_text.size[0] + 10, 0), isalpha=True)
+        usage_text_size = usage_img.img.size
         # 底部画板，大小根据table大小和usage文字大小确定
         main_menu = ImageFactory(
             Image.new(
@@ -300,9 +314,9 @@ class Template(PicTemplate):
             )
         )
         # 在底部画板上粘贴usage
-        pos, _ = main_menu.img_paste(
-            usage_text,
-            main_menu.align_box('self', usage_text, pos=(0, 130), align='horizontal'),
+        pos, a = main_menu.img_paste(
+            usage_img.img,
+            main_menu.align_box('self', usage_img.img, pos=(0, 130), align='horizontal'),
             isalpha=True
         )
         # 在底部画板上粘贴表格
@@ -328,13 +342,26 @@ class Template(PicTemplate):
         return main_menu.img
 
     def generate_original_plugin_menu(self, plugin_data: PluginMetadata) -> Image:
-        usage_text = multi_text('用法：' + plugin_data.usage,
-                                box_size=(600, 0),
+        usage_basic_text = simple_text('用法：',
+                                       size=self.basic_font_size,
+                                       color=self.colors['blue'],
+                                       font=self.using_font)
+        usage_text = multi_text(plugin_data.usage,
+                                box_size=(600 , 0),
                                 default_font=self.using_font,
                                 default_color=self.colors['blue'],
                                 default_size=self.basic_font_size
                                 )
-        usage_text_size = usage_text.size
+        # 合成usage文字图片
+        usage_img = ImageFactory(
+            Image.new('RGBA', (usage_text.size[0]+10+usage_basic_text.size[0],
+                               max((usage_text.size[1], usage_basic_text.size[1]))),
+                      self.colors['white'])
+        )
+        usage_img.img_paste(usage_basic_text, (0, 0), isalpha=True)
+        usage_img.img_paste(usage_text, (usage_basic_text.size[0] + 10, 0), isalpha=True)
+        usage_text_size = usage_img.img.size
+        # 主画布
         main_menu = ImageFactory(
             Image.new(
                 'RGBA',
@@ -343,18 +370,20 @@ class Template(PicTemplate):
                 color=self.colors['white']
             )
         )
-        # 给表格添加装饰性边框
+        # 添加边框Box
         main_menu.add_box('border_box',
                           main_menu.align_box('self',
                                               (usage_text_size[0] + 60, usage_text_size[1] + 70),
                                               pos=(0, 100),
                                               align='horizontal'),
                           (usage_text_size[0] + 70, usage_text_size[1] + 70))
+        # 粘贴usage文字图片
         main_menu.img_paste(
-            usage_text,
-            main_menu.align_box('border_box', usage_text, align='center'),
+            usage_img.img,
+            main_menu.align_box('border_box', usage_img.img, align='center'),
             isalpha=True
         )
+        # 添加装饰性边框
         main_menu.rectangle('border_box', outline=self.colors['blue'], width=5)
         border_box_top_left = main_menu.boxes['border_box'].topLeft
         main_menu.rectangle(Box((border_box_top_left[0] - 25, border_box_top_left[1] - 25),
@@ -385,7 +414,7 @@ class Template(PicTemplate):
         for x in string_list:
             text_img_list.append(
                 multi_text(x,
-                           box_size=(680-info_text_start_x, 0),
+                           box_size=(680 - info_text_start_x, 0),
                            default_font=self.using_font,
                            default_color=self.colors['blue'],
                            default_size=self.basic_font_size,
@@ -398,9 +427,11 @@ class Template(PicTemplate):
         line_max_height_list = [max(x) for x in
                                 zip(map(lambda y: y[1], text_size_list), map(lambda y: y[1], basis_text_size_list))]
         # 文字画板，每行间距30
-        text_img = ImageFactory(Image.new('RGBA',
-                                          (680, sum(line_max_height_list) + 90),
-                                          color=self.colors['white']))
+        text_img = ImageFactory(
+            Image.new('RGBA',
+                      (info_text_start_x + 40 + text_img_list[0].size[0], sum(line_max_height_list) + 90),
+                      color=self.colors['white'])
+        )
         # - 添加func的box
         text_img.add_box('func_box', (0, 0), (680, max((basis_text_size_list[0][1], text_size_list[0][1]))))
         # 粘贴func标签
@@ -484,7 +515,7 @@ class DataManager(object):
                 else:
                     menu_template = 'default'
             else:
-                self.original_plugin_names.append(meta_data.name)
+                self.original_plugin_names.append(plugin.name)
                 logger.opt(colors=True).success(f'<y>{meta_data.name}</y> 菜单数据已加载')
                 continue
             # 数据整合
@@ -517,6 +548,7 @@ class DataManager(object):
             menu_data.description for menu_data in self.plugin_menu_data_list
         ]
         for plugin_name in self.original_plugin_names:
+            print(plugin_name)
             descriptions.append(nonebot.plugin.get_plugin(plugin_name).metadata.description)
         return self.plugin_names + self.original_plugin_names, descriptions
 
